@@ -99,10 +99,11 @@ pwd
 echo Host Python Environment i.e. system-site-packages
 pip list
 echo Creating Virtual Environment
-virtualenv .task_venv --system-site-packages
+python3 -m venv --system-site-packages .task_venv
 echo Activate Environment
 . .task_venv/bin/activate
-echo $PS1
+echo Python Interpreter Location
+which python
 echo Run Main Command
 {command}
 export exit_code=$?
