@@ -60,7 +60,7 @@ def _parse_unprotected_modules_names_from_package(package: ModuleType) -> List[s
     return [m.stem for m in package_path.glob("[!_]*.py")]
 
 
-def _validate_dags(dags: List[DAG]):
+def _validate_dags(dags: List[DAG]) -> None:
     """
     Validate dags by ensuring they can be traversed without cycles and are syntactically correct
     """
@@ -71,9 +71,10 @@ def _validate_dags(dags: List[DAG]):
             raise SyntaxError(f"DAG {d.dag_id} malformed.  Parsing resulted in error: {e=}") from e
 
 
-def _validate_workflows(workflows: List[Workflow], export_path: Path):
+def _validate_workflows(workflows: List[Workflow], export_path: Path) -> None:
     """
-    Validate workflows by ensuring their exported version compiles as python
+    Validate workflows by ensuring their exported version compiles as python and that there
+    is at least one node
     """
     for w in workflows:
         try:
@@ -85,3 +86,5 @@ def _validate_workflows(workflows: List[Workflow], export_path: Path):
                 f"Workflow {w.workflow_name} malformed. "
                 f"Parsing exported workflow resulted in error: {e=}"
             ) from e
+        if len(w.nodes) == 0:
+            raise ValueError(f"Workflow {w.workflow_name} has 0 nodes.")
