@@ -44,7 +44,7 @@ class ApmTransaction:
 
     @property
     def _apm_service_name(self) -> str:
-        name = f"{self._workflow_name}_{self._workflow_version}"
+        name = f"{self._workflow_name}-{self._workflow_version}"
         name = name.replace("_", "-")
         name = name.replace(".", "-")
         return name
@@ -76,7 +76,7 @@ class ApmTransaction:
             self.transaction_name = transaction_name
             self.client = elasticapm.Client(self._apm_config)
             elasticapm.instrument()
-            self.client.begin_transaction(self.transaction_name)
+            self.client.begin_transaction(transaction_type="Task")
             logger.info(f"APM Configured: config={self._apm_config}")
         else:
             logger.warning(f"APM Not Configured")
@@ -95,17 +95,20 @@ class ApmTransaction:
             finally:
                 pass
 
-    def close(self):
+    def close(self, exc_type=None):
         if not self.configured:
             return
-        self.client.end_transaction(self.transaction_name)
+        result = "Success"
+        if exc_type is not None:
+            result = "Error"
+        self.client.end_transaction(name=self.transaction_name, result=result)
         self.client.close()
 
     def __enter__(self):
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        self.close()
+        self.close(exc_type)
         # note: exception not captured through apm due to potential size of local variables
 
 
